@@ -25,7 +25,7 @@
 #'
 #' read_lines(I(x))
 read_file <- function(file, locale = default_locale()) {
-  if (empty_file(file)) {
+  if (empty_file(file) || empty_raw(file)) {
     return("")
   }
 
@@ -36,7 +36,7 @@ read_file <- function(file, locale = default_locale()) {
 #' @export
 #' @rdname read_file
 read_file_raw <- function(file) {
-  if (empty_file(file)) {
+  if (empty_file(file) || empty_raw(file)) {
     return(raw())
   }
 
@@ -45,16 +45,9 @@ read_file_raw <- function(file) {
 }
 
 #' @inherit write_lines
-#' @param path `r lifecycle::badge("deprecated")` Use the `file` argument
-#'   instead.
 #' @rdname read_file
 #' @export
-write_file <- function(x, file, append = FALSE, path = deprecated()) {
-  if (is_present(path)) {
-    deprecate_warn("1.4.0", "write_file(path = )", "write_file(file = )")
-    file <- path
-  }
-
+write_file <- function(x, file, append = FALSE) {
   force(x)
 
   file <- standardise_path(file, input = FALSE)
