@@ -1,5 +1,3 @@
-context("Parsing, logical")
-
 test_that("TRUE and FALSE parsed", {
   expect_equal(parse_logical(c("TRUE", "FALSE")), c(TRUE, FALSE))
 })
@@ -35,6 +33,7 @@ test_that("true and false guessed", {
 
 test_that("other values generate warnings", {
   expect_warning(out <- parse_logical(c("A", "AB", "ABCD", "ABCDE", "NA")))
-  expect_equivalent(out, rep(NA, 5))
+  probs <- attr(out, "problems")
+  expect_equal(c(out), rep(NA, 5))
   expect_equal(n_problems(out), 4)
 })
